.. _vtksuite:

pymech.vtksuite
===============

This Python module contains one routine to convert from
:class:`pymech.core.HexaData` to a VTK object.

.. warning::

   The module is experimental in nature and may have some rough edges.

-------------------------------------------------------------------------------

.. _vtksuite-contents:

Contents of vtksuite.py
-----------------------

.. automodule:: pymech.vtksuite
